@@ -1,14 +1,14 @@
 # pylint: disable=unexpected-keyword-arg,no-value-for-parameter,invalid-name
 """BPR Loss with biases."""
 
-import deepr as dpr
+import deepr
 
 
 def BPRLoss(vocab_size: int):
     """BPR Loss with biases."""
-    return dpr.layers.Sequential(
-        dpr.layers.Select(inputs=("userEmbeddings", "targetPositives", "targetNegatives", "targetMask")),
-        dpr.layers.DenseIndex(
+    return deepr.layers.DAG(
+        deepr.layers.Select(inputs=("userEmbeddings", "targetPositives", "targetNegatives", "targetMask")),
+        deepr.layers.DenseIndex(
             inputs=("userEmbeddings", "targetPositives"),
             outputs="targetPositiveLogits",
             units=vocab_size,
@@ -16,7 +16,7 @@ def BPRLoss(vocab_size: int):
             bias_name="biases",
             reuse=True,
         ),
-        dpr.layers.DenseIndex(
+        deepr.layers.DenseIndex(
             inputs=("userEmbeddings", "targetNegatives"),
             outputs="targetNegativeLogits",
             units=vocab_size,
@@ -24,14 +24,14 @@ def BPRLoss(vocab_size: int):
             bias_name="biases",
             reuse=True,
         ),
-        dpr.layers.ToFloat(inputs="targetMask", outputs="targetWeight"),
-        dpr.layers.ExpandDims(inputs="targetMask", outputs="targetMask"),
-        dpr.layers.MaskedBPR(
+        deepr.layers.ToFloat(inputs="targetMask", outputs="targetWeight"),
+        deepr.layers.ExpandDims(inputs="targetMask", outputs="targetMask"),
+        deepr.layers.MaskedBPR(
             inputs=("targetPositiveLogits", "targetNegativeLogits", "targetMask", "targetWeight"), outputs="loss"
         ),
-        dpr.layers.TripletPrecision(
+        deepr.layers.TripletPrecision(
             inputs=("targetPositiveLogits", "targetNegativeLogits", "targetMask", "targetWeight"),
             outputs="triplet_precision",
         ),
-        dpr.layers.Select(inputs=("loss", "triplet_precision")),
+        deepr.layers.Select(inputs=("loss", "triplet_precision")),
     )
