@@ -3,7 +3,7 @@
 
 from typing import Optional
 
-import deepr as dpr
+import deepr
 import tensorflow as tf
 
 from deepr.examples.movielens.utils import fields as F
@@ -27,30 +27,30 @@ def CSVPrepro(
         F.INPUT_POSITIVES_ONE_HOT(vocab_size),
         F.TARGET_POSITIVES_ONE_HOT(vocab_size),
     ]
-    return dpr.prepros.Serial(
-        dpr.prepros.Map(SequenceMask(inputs="inputPositives", outputs="inputMask")),
-        dpr.prepros.Map(SequenceMask(inputs="targetPositives", outputs="targetMask")),
-        dpr.prepros.PaddedBatch(batch_size=batch_size, fields=fields),
-        dpr.prepros.Map(
+    return deepr.prepros.Serial(
+        deepr.prepros.Map(SequenceMask(inputs="inputPositives", outputs="inputMask")),
+        deepr.prepros.Map(SequenceMask(inputs="targetPositives", outputs="targetMask")),
+        deepr.prepros.PaddedBatch(batch_size=batch_size, fields=fields),
+        deepr.prepros.Map(
             RandomNegatives(
                 inputs="targetPositives", outputs="targetNegatives", num_negatives=num_negatives, vocab_size=vocab_size
             )
         )
         if num_negatives is not None
         else [],
-        dpr.prepros.Repeat(repeat_size, modes=[dpr.TRAIN]),
-        dpr.prepros.Prefetch(prefetch_size),
+        deepr.prepros.Repeat(repeat_size, modes=[deepr.TRAIN]),
+        deepr.prepros.Prefetch(prefetch_size),
         num_parallel_calls=num_parallel_calls,
     )
 
 
-@dpr.layers.layer(n_in=1, n_out=1)
+@deepr.layers.layer(n_in=1, n_out=1)
 def SequenceMask(tensors):
     size = tf.size(tensors)
     return tf.sequence_mask(size)
 
 
-@dpr.layers.layer(n_in=1, n_out=1)
+@deepr.layers.layer(n_in=1, n_out=1)
 def RandomNegatives(tensors, num_negatives, vocab_size):
     negatives = tf.random.uniform(shape=[tf.shape(tensors)[0], 1, num_negatives], maxval=vocab_size, dtype=tf.int64)
     return negatives
