@@ -1,9 +1,12 @@
 # pylint: disable=invalid-name
 """CSV Reader for MovieLens."""
 
+import logging
+import collections
+
 import tensorflow as tf
 import numpy as np
-import deepr as dpr
+import deepr
 
 from deepr.examples.movielens.utils import fields
 
@@ -20,20 +23,32 @@ except ImportError as e:
     print(f"Scipy needs to be installed for MovieLens {e}")
 
 
-class TrainCSVReader(dpr.readers.Reader):
+LOGGER = logging.getLogger(__name__)
+
+
+class TrainCSVReader(deepr.readers.Reader):
     """Reader of MovieLens CSV files of the Multi-VAE paper.
 
     See https://github.com/dawenl/vae_cf
     """
 
     def __init__(
-        self, path_csv: str, vocab_size: int, target_ratio: float = None, shuffle: bool = True, seed: int = 98765
+        self,
+        path_csv: str,
+        vocab_size: int,
+        target_ratio: float = None,
+        bucket_size: int = 16 * 512,
+        shuffle: bool = True,
+        seed: int = 42,
+        take_ratio: float = None,
     ):
         self.path_csv = path_csv
         self.vocab_size = vocab_size
         self.target_ratio = target_ratio
+        self.bucket_size = bucket_size
         self.shuffle = shuffle
         self.seed = seed
+        self.take_ratio = take_ratio
         self.fields = [
             fields.UID,
             fields.INPUT_POSITIVES,
@@ -43,23 +58,52 @@ class TrainCSVReader(dpr.readers.Reader):
         ]
 
     def as_dataset(self):
-        with dpr.io.Path(self.path_csv).open() as file:
+        with deepr.io.Path(self.path_csv).open() as file:
             tp = pd.read_csv(file)
-        n_users = tp["uid"].max() + 1
         rows, cols = tp["uid"], tp["sid"]
+        n_users = rows.max() + 1
         data = sparse.csr_matrix((np.ones_like(rows), (rows, cols)), dtype="int64", shape=(n_users, self.vocab_size))
+        LOGGER.info(f"Reloaded user-item matrix of shape {data.shape} with num_events={len(rows)}")
+        if self.take_ratio is not None:
+            data = data[: int(self.take_ratio * n_users)]
+            LOGGER.info(f"Sliced user-item matrix, new shape = {data.shape}, num_events={data.sum()}")
         np.random.seed(self.seed)
+        counts = np.array(data.sum(axis=1)).flatten()
+        if self.bucket_size:
+            buckets = collections.defaultdict(list)
+            for bucket, (_, idx) in enumerate(sorted(zip(counts, range(data.shape[0])))):
+                buckets[bucket // self.bucket_size].append(idx)
 
         def _gen():
-            idxlist = list(range(data.shape[0]))
+            # Resolve idxlist (shuffle + buckets)
             if self.shuffle:
-                np.random.shuffle(idxlist)
+                if self.bucket_size:
+                    idxlist = []
+                    # Shuffle buckets
+                    bucket_idx = list(range(len(buckets)))
+                    np.random.shuffle(bucket_idx)
+                    for idx in bucket_idx:
+                        # Shuffle bucket indices
+                        bucket_idxlist = buckets[idx]
+                        np.random.shuffle(bucket_idxlist)
+                        idxlist.extend(bucket_idxlist)
+                else:
+                    idxlist = list(range(data.shape[0]))
+                    np.random.shuffle(idxlist)
+            else:
+                if self.bucket_size:
+                    idxlist = [idx for _, idx in sorted(zip(counts, range(data.shape[0])))]
+                else:
+                    idxlist = list(range(data.shape[0]))
+
+            # Iterate over items in the sparse matrix
             for idx in idxlist:
                 X = data[idx]
                 if sparse.isspmatrix(X):
                     X = X.toarray()
                 X = X.astype("int64")
                 indices = np.nonzero(X[0])[0]
+                # Split into input / target
                 if self.target_ratio is not None:
                     np.random.shuffle(indices)
                     size = int(len(indices) * (1 - self.target_ratio))
@@ -69,6 +113,7 @@ class TrainCSVReader(dpr.readers.Reader):
                     input_one_hot[input_positives] = 1
                     target_one_hot = np.zeros((self.vocab_size,), dtype=np.int64)
                     target_one_hot[target_positives] = 1
+                # Same input / target
                 else:
                     input_positives = indices
                     target_positives = indices
@@ -89,7 +134,7 @@ class TrainCSVReader(dpr.readers.Reader):
         )
 
 
-class TestCSVReader(dpr.readers.Reader):
+class TestCSVReader(deepr.readers.Reader):
     """Reader of MovieLens test CSV files of the Multi-VAE paper.
 
     See https://github.com/dawenl/vae_cf
@@ -108,9 +153,9 @@ class TestCSVReader(dpr.readers.Reader):
         ]
 
     def as_dataset(self):
-        with dpr.io.Path(self.path_csv_tr).open() as file:
+        with deepr.io.Path(self.path_csv_tr).open() as file:
             tp_tr = pd.read_csv(file)
-        with dpr.io.Path(self.path_csv_te).open() as file:
+        with deepr.io.Path(self.path_csv_te).open() as file:
             tp_te = pd.read_csv(file)
 
         start_idx = min(tp_tr["uid"].min(), tp_te["uid"].min())
