@@ -4,6 +4,7 @@ from deepr.jobs.base import Job
 from deepr.jobs.cleanup_checkpoints import CleanupCheckpoints
 from deepr.jobs.combinators import Pipeline
 from deepr.jobs.copy_dir import CopyDir
+from deepr.jobs.evaluate import Evaluate
 from deepr.jobs.log_metric import LogMetric
 from deepr.jobs.mlflow_save_configs import MLFlowFormatter, MLFlowSaveConfigs
 from deepr.jobs.mlflow_save_info import MLFlowSaveInfo
@@ -11,6 +12,8 @@ from deepr.jobs.optimize_saved_model import OptimizeSavedModel
 from deepr.jobs.export_xla_model_metadata import ExportXlaModelMetadata
 from deepr.jobs.params_tuner import ParamsTuner, GridSampler, ParamsSampler, Sampler
 from deepr.jobs.save_dataset import SaveDataset
-from deepr.jobs.trainer import Trainer, TrainSpec, EvalSpec, RunConfig, ConfigProto
+from deepr.jobs.trainer_base import TrainerBase
+from deepr.jobs.trainer import Trainer, TrainSpec, EvalSpec, FinalSpec, RunConfig, ConfigProto
+from deepr.jobs.trainer_keras import TrainerKeras
 from deepr.jobs.yarn_launcher import YarnLauncherConfig, YarnLauncher
 from deepr.jobs.yarn_trainer import YarnTrainerConfig, YarnTrainer
